netapp_ontap.models.nvme_namespace_space_guarantee API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.nvme_namespace_space_guarantee`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NvmeNamespaceSpaceGuaranteeSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NvmeNamespaceSpaceGuarantee object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `requested GET`

    The requested space reservation policy for the NVMe namespace. If true, a space reservation is requested for the namespace; if false, the namespace is thin provisioned. Guaranteeing a space reservation request for a namespace requires that the volume in which the namespace resides also be space reserved and that the fractional reserve for the volume be 100%.
    The space reservation policy for an NVMe namespace is determined by ONTAP.

  `reserved GET`

    Reports if the NVMe namespace is space guaranteed.
    This property is true if a space guarantee is requested and the containing volume and aggregate support the request. This property is false if a space guarantee is not requested or if a space guarantee is requested and either the containing volume and aggregate do not support the request.